.. _reference:

API reference
=============

Axes offers extensible APIs that you can customize to your liking.
You can specialize the following base classes or alternatively use
third party modules as long as they implement the following APIs.

.. automodule:: axes.handlers.base
   :members:

.. automodule:: axes.backends
   :members:
   :show-inheritance:

.. automodule:: axes.middleware
   :members:
